.. Places parent toc into the sidebar

.. title:: User guide: contents

.. _user_guide:

==========
User Guide
==========

.. include:: includes/big_toc_css.rst

.. nice layout in the toc

.. include:: tune_toc.rst

.. toctree::
   :numbered:
   :maxdepth: 2

   analysis.rst
   base.rst
   cases.rst 
   datasets.rst 
   methods.rst 
   utils.rst
   view.rst


